@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
+# cython: language_level=3, always_allow_keywords=True
 
-## Copyright 2009-2012 by LivingLogic AG, Bayreuth/Germany
-## Copyright 2009-2012 by Walter Dörwald
+## Copyright 2009-2014 by LivingLogic AG, Bayreuth/Germany
+## Copyright 2009-2014 by Walter Dörwald
 ##
 ## All Rights Reserved
 ##
@@ -12,6 +13,17 @@ from ll import misc
 from ll.xist import xsc
 
 
+###
+### Processing instruction for comments
+###
+
+class note(xsc.ProcInst):
+	"""
+	A :class:`note` processing instruction contains a comment (which will be
+	ignored when compiling the template).
+	"""
+
+
 ###
 ### Processing instructions for output
 ###
@@ -37,17 +49,7 @@ class printx(xsc.ProcInst):
 class code(xsc.ProcInst):
 	"""
 	A :class:`code` processing instruction contains a statement (such as an
-	assignment or augmented assignment).
-	"""
-
-
-###
-### Processing instruction for calling sub-templates
-###
-
-class render(xsc.ProcInst):
-	"""
-	A :class:`render` processing instruction calls another template.
+	assignment or augmented assignment) or expressions (with side effects).
 	"""
 
 
@@ -114,9 +116,10 @@ class else_(xsc.ProcInst):
 
 class end(xsc.ProcInst):
 	"""
-	Ends an :class:`if_` or :class:`for_`. The PI value may be the type of the
-	block (either ``"if"``, ``"for"`` or ``"def"``). If the value is empty the
-	innermost block will be closed without any checks for the type of block.
+	Ends an :class:`if_`, :class:`for_` or :class:`def_`. The PI value may be the
+	type of the block (either ``"if"``, ``"for"`` or ``"def"``). If the value is
+	empty the innermost block will be closed without any checks for the type of
+	block.
 	"""
 	prettyindentbefore = -1
 	prettyindentafter = 0
@@ -136,6 +139,10 @@ class continue_(xsc.ProcInst):
 	xmlname = "continue"
 
 
+class return_(xsc.ProcInst):
+	xmlname = "return"
+
+
 class def_(xsc.ProcInst):
 	xmlname = "def"
 	prettyindentbefore = 0
